"""
Tests for ingest_envoy.ingest
"""
import argparse
from unittest.mock import patch, MagicMock

import ingest_envoy.ingest as ingest

expected_settings = {
    "sdmId": "16B-069_sb32814386_1_001.57685.66193635417",
    "workflowName": "std_calibration",
    "spl": "uid://evla/execblock/48ba4c9d-d7c7-4a8f-9803-1115cd52459b",
    "processingStart": "2021_07_06T21_50_48",
    "destinationDir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmp576dknjp",
    "workflowDir": "tmp576dknjp",
    "staging_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/staging",
    "storage_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/storage",
}

args = argparse.Namespace
filename = "test/input_files/test-metadata.json"


class TestIngest:
    def test_get_settings(self):
        settings = ingest._get_settings(filename)
        assert settings["sdmId"] == expected_settings["sdmId"]
        assert settings["workflowName"] == expected_settings["workflowName"]
        assert settings["spl"] == expected_settings["spl"]
        assert settings["processingStart"] == expected_settings["processingStart"]
        assert settings["destinationDir"] == expected_settings["destinationDir"]
        assert settings["workflowDir"] == expected_settings["workflowDir"]
        assert settings["staging_area"] == expected_settings["staging_area"]
        assert settings["storage_area"] == expected_settings["storage_area"]

    def test_check_ingest_type(self):
        arg_type = "calibration"
        arg_type2 = "image"

        check = ingest.check_ingest_type(arg_type, expected_settings)
        assert check is True

        check2 = ingest.check_ingest_type(arg_type2, expected_settings)
        assert check2 is False

    def test_parser(self):
        parser = ingest.arg_parser()
        assert isinstance(parser, argparse.ArgumentParser)

    def test_main_calibration(self):
        args.calibration = [filename]

        with patch("argparse.ArgumentParser.parse_args", MagicMock(return_value=args)) as mock_args:
            with patch(
                "ingest_envoy.launchers.IngestCalibrationLauncher.launch_ingestion"
            ) as cal_ingest:
                ingest.main()
                assert cal_ingest.call_count == 1

        # reset for other testing
        args.calibration = None
